poreencode — Translate Toolkit 3.3.0 documentation

# poreencode

Takes a directory of existing PO files and converts them to a given encoding.

## Prerequisites

GNU Gettext

## Usage

    poreencode <encoding> <PO directory>

Where:

encoding | is the encoding you would like to convert to e.g. UTF-8
PO directory | is a directory of existing PO files

It is best to backup files before the conversion or to perform it against CVS which prevents a potential loss of data.

## Operation

poreencode makes use of the Gettext tool msgconv to perform its task. It traverses the PO directory and finds all PO file. It uses msgconv to convert the PO file from its existing encoding to the new encoding.

## Bugs

Like most Gettext tools they do a little bit more than documented, msgconv will decide which strings are in fact fuzzy and delete fuzzy marking – not a lot but you do need to diff (this probably related to #, fuzzy entries that are not placed in the place Gettext expects them).